{{#include ../../../shared/blockquote-info.html}}

# The Glean JavaScript SDK provides a slightly different set of metrics and pings

> If you are looking for the metrics collected by Glean.js,
> refer to the documentation over on the [`@mozilla/glean.js`](https://github.com/mozilla/glean.js/blob/main/docs/reference/metrics.md) repository.
